pub struct MaxBuildCount(/* private fields */);Trait Implementations
Sourceimpl Debug for MaxBuildCount
impl Debug for MaxBuildCount
Sourceimpl Default for MaxBuildCount
impl Default for MaxBuildCount
Sourceimpl<'de> Deserialize<'de> for MaxBuildCount
impl<'de> Deserialize<'de> for MaxBuildCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<MaxBuildCount> for u8
impl From<MaxBuildCount> for u8
Sourcefn from(count: MaxBuildCount) -> Self
fn from(count: MaxBuildCount) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for MaxBuildCount
impl JsonSchema for MaxBuildCount
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MaxBuildCount
impl PartialEq for MaxBuildCount
Sourceimpl Serialize for MaxBuildCount
impl Serialize for MaxBuildCount
impl StructuralPartialEq for MaxBuildCount